# io.swagger.client - Kotlin client library for Risk Analytics - A Weather Source API

## Requires

* Kotlin 1.4.30
* Gradle 5.3

## Build

First, create the gradle wrapper script:

```
gradle wrapper
```

Then, run:

```
./gradlew check assemble
```

This runs all tests and packages the library.

## Features/Implementation Notes

* Supports JSON inputs/outputs, File inputs, and Form inputs.
* Supports collection formats for query parameters: csv, tsv, ssv, pipes.
* Some Kotlin and Java types are fully qualified to avoid conflicts with types defined in Swagger definitions.
* Implementation of ApiClient is intended to reduce method counts, specifically to benefit Android targets.

<a name="documentation-for-api-endpoints"></a>
## Documentation for API Endpoints

All URIs are relative to *https://risk.weathersourceapis.com/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*PointsApi* | [**pointsLatitudelongitudeHazardsColdwaveRecurrenceintervalRecurranceIntervalCategoryCategoryGet**](docs/PointsApi.md#pointslatitudelongitudehazardscoldwaverecurrenceintervalrecurranceintervalcategorycategoryget) | **GET** /points/{latitude},{longitude}/hazards/coldwave/recurrenceinterval/{recurranceInterval}/category/{category} | The Cold Wave risk for a Latitude/Longitude point.
*PointsApi* | [**pointsLatitudelongitudeHazardsDroughtRecurrenceintervalRecurranceIntervalCategoryCategoryGet**](docs/PointsApi.md#pointslatitudelongitudehazardsdroughtrecurrenceintervalrecurranceintervalcategorycategoryget) | **GET** /points/{latitude},{longitude}/hazards/drought/recurrenceinterval/{recurranceInterval}/category/{category} | The Drought risk for a Latitude/Longitude point.
*PointsApi* | [**pointsLatitudelongitudeHazardsEarthquakeRecurrenceintervalRecurranceIntervalCategoryCategoryGet**](docs/PointsApi.md#pointslatitudelongitudehazardsearthquakerecurrenceintervalrecurranceintervalcategorycategoryget) | **GET** /points/{latitude},{longitude}/hazards/earthquake/recurrenceinterval/{recurranceInterval}/category/{category} | The Earthquake risk for a Latitude/Longitude point.
*PointsApi* | [**pointsLatitudelongitudeHazardsFloodRecurrenceintervalRecurranceIntervalGet**](docs/PointsApi.md#pointslatitudelongitudehazardsfloodrecurrenceintervalrecurranceintervalget) | **GET** /points/{latitude},{longitude}/hazards/flood/recurrenceinterval/{recurranceInterval} | The Flood risk for a Latitude/Longitude point.
*PointsApi* | [**pointsLatitudelongitudeHazardsHailRecurrenceintervalRecurranceIntervalCategoryCategoryGet**](docs/PointsApi.md#pointslatitudelongitudehazardshailrecurrenceintervalrecurranceintervalcategorycategoryget) | **GET** /points/{latitude},{longitude}/hazards/hail/recurrenceinterval/{recurranceInterval}/category/{category} | The Hail risk for a Latitude/Longitude point.
*PointsApi* | [**pointsLatitudelongitudeHazardsHeatwaveRecurrenceintervalRecurranceIntervalCategoryCategoryGet**](docs/PointsApi.md#pointslatitudelongitudehazardsheatwaverecurrenceintervalrecurranceintervalcategorycategoryget) | **GET** /points/{latitude},{longitude}/hazards/heatwave/recurrenceinterval/{recurranceInterval}/category/{category} | The Heat Wave risk for a Latitude/Longitude point.
*PointsApi* | [**pointsLatitudelongitudeHazardsTornadoRecurrenceintervalRecurranceIntervalCategoryCategoryGet**](docs/PointsApi.md#pointslatitudelongitudehazardstornadorecurrenceintervalrecurranceintervalcategorycategoryget) | **GET** /points/{latitude},{longitude}/hazards/tornado/recurrenceinterval/{recurranceInterval}/category/{category} | The Tornado risk for a Latitude/Longitude point.
*PointsApi* | [**pointsLatitudelongitudeHazardsTropicalcycloneRecurrenceintervalRecurranceIntervalCategoryCategoryGet**](docs/PointsApi.md#pointslatitudelongitudehazardstropicalcyclonerecurrenceintervalrecurranceintervalcategorycategoryget) | **GET** /points/{latitude},{longitude}/hazards/tropicalcyclone/recurrenceinterval/{recurranceInterval}/category/{category} | The Tropical Cyclone risk for a Latitude/Longitude point.
*PointsApi* | [**pointsLatitudelongitudeHazardsTsunamiRecurrenceintervalRecurranceIntervalCategoryCategoryGet**](docs/PointsApi.md#pointslatitudelongitudehazardstsunamirecurrenceintervalrecurranceintervalcategorycategoryget) | **GET** /points/{latitude},{longitude}/hazards/tsunami/recurrenceinterval/{recurranceInterval}/category/{category} | The Tsunami risk for a Latitude/Longitude point.
*PointsApi* | [**pointsLatitudelongitudeHazardsVolcanoRecurrenceintervalRecurranceIntervalCategoryCategoryGet**](docs/PointsApi.md#pointslatitudelongitudehazardsvolcanorecurrenceintervalrecurranceintervalcategorycategoryget) | **GET** /points/{latitude},{longitude}/hazards/volcano/recurrenceinterval/{recurranceInterval}/category/{category} | The Volcano risk for a Latitude/Longitude point.
*PointsApi* | [**pointsLatitudelongitudeHazardsWildfireRecurrenceintervalRecurranceIntervalCategoryCategoryGet**](docs/PointsApi.md#pointslatitudelongitudehazardswildfirerecurrenceintervalrecurranceintervalcategorycategoryget) | **GET** /points/{latitude},{longitude}/hazards/wildfire/recurrenceinterval/{recurranceInterval}/category/{category} | The Wildfire risk for a Latitude/Longitude point.
*PointsApi* | [**versionsGet**](docs/PointsApi.md#versionsget) | **GET** /versions | The current data version for all hazard data sources.

<a name="documentation-for-models"></a>
## Documentation for Models

 - [io.swagger.client.models.BoundingPoints](docs/BoundingPoints.md)
 - [io.swagger.client.models.BoundingPointsInner](docs/BoundingPointsInner.md)
 - [io.swagger.client.models.Category](docs/Category.md)
 - [io.swagger.client.models.CountryCode](docs/CountryCode.md)
 - [io.swagger.client.models.CountryName](docs/CountryName.md)
 - [io.swagger.client.models.Distance](docs/Distance.md)
 - [io.swagger.client.models.Elevation](docs/Elevation.md)
 - [io.swagger.client.models.ErrorObj](docs/ErrorObj.md)
 - [io.swagger.client.models.ExtremeValueFlood](docs/ExtremeValueFlood.md)
 - [io.swagger.client.models.ExtremeValueNull](docs/ExtremeValueNull.md)
 - [io.swagger.client.models.ExtremeValueTropicalCyclone](docs/ExtremeValueTropicalCyclone.md)
 - [io.swagger.client.models.FieldListFloodObj](docs/FieldListFloodObj.md)
 - [io.swagger.client.models.FieldListProbObj](docs/FieldListProbObj.md)
 - [io.swagger.client.models.FieldListTropicalCycloneObj](docs/FieldListTropicalCycloneObj.md)
 - [io.swagger.client.models.Fields](docs/Fields.md)
 - [io.swagger.client.models.Grid](docs/Grid.md)
 - [io.swagger.client.models.Latitude](docs/Latitude.md)
 - [io.swagger.client.models.Longitude](docs/Longitude.md)
 - [io.swagger.client.models.OnpointId](docs/OnpointId.md)
 - [io.swagger.client.models.PointObj](docs/PointObj.md)
 - [io.swagger.client.models.Prob](docs/Prob.md)
 - [io.swagger.client.models.ProbNull](docs/ProbNull.md)
 - [io.swagger.client.models.RecurranceInterval](docs/RecurranceInterval.md)
 - [io.swagger.client.models.RiskColdWavePointObj](docs/RiskColdWavePointObj.md)
 - [io.swagger.client.models.RiskDroughtPointObj](docs/RiskDroughtPointObj.md)
 - [io.swagger.client.models.RiskEarthquakePointObj](docs/RiskEarthquakePointObj.md)
 - [io.swagger.client.models.RiskFloodObj](docs/RiskFloodObj.md)
 - [io.swagger.client.models.RiskFloodPointObj](docs/RiskFloodPointObj.md)
 - [io.swagger.client.models.RiskHailPointObj](docs/RiskHailPointObj.md)
 - [io.swagger.client.models.RiskHeatWavePointObj](docs/RiskHeatWavePointObj.md)
 - [io.swagger.client.models.RiskMetadataObj](docs/RiskMetadataObj.md)
 - [io.swagger.client.models.RiskProbObj](docs/RiskProbObj.md)
 - [io.swagger.client.models.RiskTornadoPointObj](docs/RiskTornadoPointObj.md)
 - [io.swagger.client.models.RiskTropicalCycloneObj](docs/RiskTropicalCycloneObj.md)
 - [io.swagger.client.models.RiskTropicalCyclonePointObj](docs/RiskTropicalCyclonePointObj.md)
 - [io.swagger.client.models.RiskTsunamiPointObj](docs/RiskTsunamiPointObj.md)
 - [io.swagger.client.models.RiskVolcanoPointObj](docs/RiskVolcanoPointObj.md)
 - [io.swagger.client.models.RiskWildfirePointObj](docs/RiskWildfirePointObj.md)
 - [io.swagger.client.models.SubdivCode](docs/SubdivCode.md)
 - [io.swagger.client.models.SubdivName](docs/SubdivName.md)
 - [io.swagger.client.models.Timezone](docs/Timezone.md)
 - [io.swagger.client.models.Version](docs/Version.md)
 - [io.swagger.client.models.VersionsObj](docs/VersionsObj.md)

<a name="documentation-for-authorization"></a>
## Documentation for Authorization

<a name="ApiKeyAuth"></a>
### ApiKeyAuth


