/**
 * Risk Analytics - A Weather Source API
 * Analytics for weather, climate and environmental risks for latitude/longitude points. The Risk Analytics API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate analysis. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.    **IMPORTANT:** To authenticate to the Weather Source Risk Analytics API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.      When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
 *
 * OpenAPI spec version: 2.0.0
 * Contact: support@weathersource.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */
package io.swagger.client.apis

import io.swagger.client.models.ErrorObj
import io.swagger.client.models.RiskColdWavePointObj
import io.swagger.client.models.RiskDroughtPointObj
import io.swagger.client.models.RiskEarthquakePointObj
import io.swagger.client.models.RiskFloodPointObj
import io.swagger.client.models.RiskHailPointObj
import io.swagger.client.models.RiskHeatWavePointObj
import io.swagger.client.models.RiskTornadoPointObj
import io.swagger.client.models.RiskTropicalCyclonePointObj
import io.swagger.client.models.RiskTsunamiPointObj
import io.swagger.client.models.RiskVolcanoPointObj
import io.swagger.client.models.RiskWildfirePointObj
import io.swagger.client.models.VersionsObj

import io.swagger.client.infrastructure.*

class PointsApi(basePath: kotlin.String = "https://risk.weathersourceapis.com/v2") : ApiClient(basePath) {

    /**
     * The Cold Wave risk for a Latitude/Longitude point.
     * Returns the Cold Wave Risk Analytics data for a Latitude/Longitude point with the given recurrence interval and a magnitude at or higher than the specified category.          **IMPORTANT:** To authenticate to the Weather Source Risk Analytics API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     * @param latitude A latitude value between -90° and 90°. 
     * @param longitude A longitude value between -180° (West) and 180° (East). 
     * @param recurranceInterval The recurrence interval for the target risk.  Valid recurrence intervals are: * 1_YEAR * 5_YEAR * 10_YEAR * 20_YEAR  
     * @param category The category for the target risk. The risk corrolates to the selected category or higher. For example, CAT_3_DAY would return risk for an event of category 3-day or longer occuring.  Valid categories are: * &#x60;CAT_3_DAY&#x60; -  3-day cold wave or longer * &#x60;CAT_5_DAY&#x60; -  5-day cold wave or longer  
     * @return RiskColdWavePointObj
     */
    @Suppress("UNCHECKED_CAST")
    fun pointsLatitudelongitudeHazardsColdwaveRecurrenceintervalRecurranceIntervalCategoryCategoryGet(latitude: kotlin.Float, longitude: kotlin.Float, recurranceInterval: kotlin.String, category: kotlin.String): RiskColdWavePointObj {
        
        val localVariableConfig = RequestConfig(
                RequestMethod.GET,
                "/points/{latitude},{longitude}/hazards/coldwave/recurrenceinterval/{recurranceInterval}/category/{category}".replace("{" + "latitude" + "}", "$latitude").replace("{" + "longitude" + "}", "$longitude").replace("{" + "recurranceInterval" + "}", "$recurranceInterval").replace("{" + "category" + "}", "$category")
        )
        val response = request<RiskColdWavePointObj>(
                localVariableConfig
        )

        return when (response.responseType) {
            ResponseType.Success -> (response as Success<*>).data as RiskColdWavePointObj
            ResponseType.Informational -> TODO()
            ResponseType.Redirection -> TODO()
            ResponseType.ClientError -> throw ClientException((response as ClientError<*>).body as? String ?: "Client error")
            ResponseType.ServerError -> throw ServerException((response as ServerError<*>).message ?: "Server error")
        }
    }
    /**
     * The Drought risk for a Latitude/Longitude point.
     * Returns the Drought Risk Analytics data for a Latitude/Longitude point with the given recurrence interval and a magnitude at or higher than the specified category.          **IMPORTANT:** To authenticate to the Weather Source Risk Analytics API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     * @param latitude A latitude value between -90° and 90°. 
     * @param longitude A longitude value between -180° (West) and 180° (East). 
     * @param recurranceInterval The recurrence interval for the target risk.  Valid recurrence intervals are: * 1_YEAR * 5_YEAR * 10_YEAR * 20_YEAR  
     * @param category The category (SPI Magnitude) for the target risk. The risk corrolates to the selected category or higher. For example, CAT_1 would return risk for an event of category 1 or higher occuring.  Valid categories are: * &#x60;CAT_1&#x60; -  Category 1 or higher * &#x60;CAT_1_5&#x60; -  Category 1.5 or higher * &#x60;CAT_2&#x60; -  Category 2 or higher * &#x60;CAT_2_5&#x60; -  Category 2.5 or higher * &#x60;CAT_3&#x60; -  Category 3 or higher * &#x60;CAT_3_5&#x60; -  Category 3.5 or higher * &#x60;CAT_4&#x60; -  Category 4 or higher * &#x60;CAT_4_5&#x60; -  Category 4.5 or higher * &#x60;CAT_5&#x60; -  Category 5  
     * @return RiskDroughtPointObj
     */
    @Suppress("UNCHECKED_CAST")
    fun pointsLatitudelongitudeHazardsDroughtRecurrenceintervalRecurranceIntervalCategoryCategoryGet(latitude: kotlin.Float, longitude: kotlin.Float, recurranceInterval: kotlin.String, category: kotlin.String): RiskDroughtPointObj {
        
        val localVariableConfig = RequestConfig(
                RequestMethod.GET,
                "/points/{latitude},{longitude}/hazards/drought/recurrenceinterval/{recurranceInterval}/category/{category}".replace("{" + "latitude" + "}", "$latitude").replace("{" + "longitude" + "}", "$longitude").replace("{" + "recurranceInterval" + "}", "$recurranceInterval").replace("{" + "category" + "}", "$category")
        )
        val response = request<RiskDroughtPointObj>(
                localVariableConfig
        )

        return when (response.responseType) {
            ResponseType.Success -> (response as Success<*>).data as RiskDroughtPointObj
            ResponseType.Informational -> TODO()
            ResponseType.Redirection -> TODO()
            ResponseType.ClientError -> throw ClientException((response as ClientError<*>).body as? String ?: "Client error")
            ResponseType.ServerError -> throw ServerException((response as ServerError<*>).message ?: "Server error")
        }
    }
    /**
     * The Earthquake risk for a Latitude/Longitude point.
     * Returns the Earthquake Risk Analytics data for a Latitude/Longitude point with the given recurrence interval and a magnitude at or higher than the specified category.          **IMPORTANT:** To authenticate to the Weather Source Risk Analytics API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     * @param latitude A latitude value between -90° and 90°. 
     * @param longitude A longitude value between -180° (West) and 180° (East). 
     * @param recurranceInterval The recurrence interval for the target risk.  Valid recurrence intervals are: * 1_YEAR * 5_YEAR * 10_YEAR * 20_YEAR * 50_YEAR * 75_YEAR * 100_YEAR  
     * @param category The category (Gutenberg Richter value) for the target risk. The risk corrolates to the selected category or higher. For example, CAT_1 would return risk for an event of category 1 or higher occuring.  Valid categories are: * &#x60;CAT_1&#x60; -  Category 1 or higher * &#x60;CAT_2&#x60; -  Category 2 or higher * &#x60;CAT_3&#x60; -  Category 3 or higher * &#x60;CAT_4&#x60; -  Category 4 or higher * &#x60;CAT_5&#x60; -  Category 5 or higher * &#x60;CAT_6&#x60; -  Category 6 or higher * &#x60;CAT_7&#x60; -  Category 7 or higher * &#x60;CAT_8&#x60; -  Category 8 or higher * &#x60;CAT_9&#x60; -  Category 9  
     * @return RiskEarthquakePointObj
     */
    @Suppress("UNCHECKED_CAST")
    fun pointsLatitudelongitudeHazardsEarthquakeRecurrenceintervalRecurranceIntervalCategoryCategoryGet(latitude: kotlin.Float, longitude: kotlin.Float, recurranceInterval: kotlin.String, category: kotlin.String): RiskEarthquakePointObj {
        
        val localVariableConfig = RequestConfig(
                RequestMethod.GET,
                "/points/{latitude},{longitude}/hazards/earthquake/recurrenceinterval/{recurranceInterval}/category/{category}".replace("{" + "latitude" + "}", "$latitude").replace("{" + "longitude" + "}", "$longitude").replace("{" + "recurranceInterval" + "}", "$recurranceInterval").replace("{" + "category" + "}", "$category")
        )
        val response = request<RiskEarthquakePointObj>(
                localVariableConfig
        )

        return when (response.responseType) {
            ResponseType.Success -> (response as Success<*>).data as RiskEarthquakePointObj
            ResponseType.Informational -> TODO()
            ResponseType.Redirection -> TODO()
            ResponseType.ClientError -> throw ClientException((response as ClientError<*>).body as? String ?: "Client error")
            ResponseType.ServerError -> throw ServerException((response as ServerError<*>).message ?: "Server error")
        }
    }
    /**
     * The Flood risk for a Latitude/Longitude point.
     * Returns the Flood Risk Analytics data for a Latitude/Longitude point.          **IMPORTANT:** To authenticate to the Weather Source Risk Analytics API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     * @param latitude A latitude value between -90° and 90°. 
     * @param longitude A longitude value between -180° (West) and 180° (East). 
     * @param recurranceInterval The recurrence interval for the target risk.  Valid recurrence intervals are: * 1_YEAR * 5_YEAR * 10_YEAR * 20_YEAR * 50_YEAR * 75_YEAR * 100_YEAR  
     * @return RiskFloodPointObj
     */
    @Suppress("UNCHECKED_CAST")
    fun pointsLatitudelongitudeHazardsFloodRecurrenceintervalRecurranceIntervalGet(latitude: kotlin.Float, longitude: kotlin.Float, recurranceInterval: kotlin.String): RiskFloodPointObj {
        
        val localVariableConfig = RequestConfig(
                RequestMethod.GET,
                "/points/{latitude},{longitude}/hazards/flood/recurrenceinterval/{recurranceInterval}".replace("{" + "latitude" + "}", "$latitude").replace("{" + "longitude" + "}", "$longitude").replace("{" + "recurranceInterval" + "}", "$recurranceInterval")
        )
        val response = request<RiskFloodPointObj>(
                localVariableConfig
        )

        return when (response.responseType) {
            ResponseType.Success -> (response as Success<*>).data as RiskFloodPointObj
            ResponseType.Informational -> TODO()
            ResponseType.Redirection -> TODO()
            ResponseType.ClientError -> throw ClientException((response as ClientError<*>).body as? String ?: "Client error")
            ResponseType.ServerError -> throw ServerException((response as ServerError<*>).message ?: "Server error")
        }
    }
    /**
     * The Hail risk for a Latitude/Longitude point.
     * Returns the Hail Risk Analytics data for a Latitude/Longitude point with the given recurrence interval and a magnitude at or higher than the specified category.          **IMPORTANT:** To authenticate to the Weather Source Risk Analytics API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     * @param latitude A latitude value between -90° and 90°. 
     * @param longitude A longitude value between -180° (West) and 180° (East). 
     * @param recurranceInterval The recurrence interval for the target risk.  Valid recurrence intervals are: * 1_YEAR * 5_YEAR * 10_YEAR * 20_YEAR  
     * @param category The category for the target risk. The risk corrolates to the selected category or higher. For example, CAT_SEVERE would return risk for an event of category Severe or higher occuring.  Valid categories are: * &#x60;CAT_SEVERE&#x60; -  Category Severe or higher (&gt;&#x3D; .75-inches) * &#x60;CAT_LARGE&#x60; -  Category Severe Large or higher (&gt;&#x3D; 1.25-inches) * &#x60;CAT_VERY_LARGE&#x60; -  Category Severe Very Large or higher (&gt;&#x3D; 1.75-inches) * &#x60;CAT_GIANT&#x60; -  Category Severe Giant (&gt;&#x3D; 2.75-inches)  
     * @return RiskHailPointObj
     */
    @Suppress("UNCHECKED_CAST")
    fun pointsLatitudelongitudeHazardsHailRecurrenceintervalRecurranceIntervalCategoryCategoryGet(latitude: kotlin.Float, longitude: kotlin.Float, recurranceInterval: kotlin.String, category: kotlin.String): RiskHailPointObj {
        
        val localVariableConfig = RequestConfig(
                RequestMethod.GET,
                "/points/{latitude},{longitude}/hazards/hail/recurrenceinterval/{recurranceInterval}/category/{category}".replace("{" + "latitude" + "}", "$latitude").replace("{" + "longitude" + "}", "$longitude").replace("{" + "recurranceInterval" + "}", "$recurranceInterval").replace("{" + "category" + "}", "$category")
        )
        val response = request<RiskHailPointObj>(
                localVariableConfig
        )

        return when (response.responseType) {
            ResponseType.Success -> (response as Success<*>).data as RiskHailPointObj
            ResponseType.Informational -> TODO()
            ResponseType.Redirection -> TODO()
            ResponseType.ClientError -> throw ClientException((response as ClientError<*>).body as? String ?: "Client error")
            ResponseType.ServerError -> throw ServerException((response as ServerError<*>).message ?: "Server error")
        }
    }
    /**
     * The Heat Wave risk for a Latitude/Longitude point.
     * Returns the Heat Wave Risk Analytics data for a Latitude/Longitude point with the given recurrence interval and a magnitude at or higher than the specified category.          **IMPORTANT:** To authenticate to the Weather Source Risk Analytics API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     * @param latitude A latitude value between -90° and 90°. 
     * @param longitude A longitude value between -180° (West) and 180° (East). 
     * @param recurranceInterval The recurrence interval for the target risk.  Valid recurrence intervals are: * 1_YEAR * 5_YEAR * 10_YEAR * 20_YEAR  
     * @param category The category for the target risk. The risk corrolates to the selected category or higher. For example, CAT_3_DAY would return risk for an event of category 3-day or longer occuring.  Valid categories are: * &#x60;CAT_3_DAY&#x60; -  3-day heat wave or longer * &#x60;CAT_5_DAY&#x60; -  5-day heat wave or longer  
     * @return RiskHeatWavePointObj
     */
    @Suppress("UNCHECKED_CAST")
    fun pointsLatitudelongitudeHazardsHeatwaveRecurrenceintervalRecurranceIntervalCategoryCategoryGet(latitude: kotlin.Float, longitude: kotlin.Float, recurranceInterval: kotlin.String, category: kotlin.String): RiskHeatWavePointObj {
        
        val localVariableConfig = RequestConfig(
                RequestMethod.GET,
                "/points/{latitude},{longitude}/hazards/heatwave/recurrenceinterval/{recurranceInterval}/category/{category}".replace("{" + "latitude" + "}", "$latitude").replace("{" + "longitude" + "}", "$longitude").replace("{" + "recurranceInterval" + "}", "$recurranceInterval").replace("{" + "category" + "}", "$category")
        )
        val response = request<RiskHeatWavePointObj>(
                localVariableConfig
        )

        return when (response.responseType) {
            ResponseType.Success -> (response as Success<*>).data as RiskHeatWavePointObj
            ResponseType.Informational -> TODO()
            ResponseType.Redirection -> TODO()
            ResponseType.ClientError -> throw ClientException((response as ClientError<*>).body as? String ?: "Client error")
            ResponseType.ServerError -> throw ServerException((response as ServerError<*>).message ?: "Server error")
        }
    }
    /**
     * The Tornado risk for a Latitude/Longitude point.
     * Returns the Tornado Risk Analytics data for a Latitude/Longitude point with the given recurrence interval and a magnitude at or higher than the specified category.          **IMPORTANT:** To authenticate to the Weather Source Risk Analytics API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     * @param latitude A latitude value between -90° and 90°. 
     * @param longitude A longitude value between -180° (West) and 180° (East). 
     * @param recurranceInterval The recurrence interval for the target risk.  Valid recurrence intervals are: * 1_YEAR * 5_YEAR * 10_YEAR * 20_YEAR  
     * @param category The category (Enhanced Fugita Scale) for the target risk. The risk corrolates to the selected category or higher. For example, CAT_EF1 would return risk for an event of category EF1 or higher occuring.  Valid categories are: * &#x60;CAT_EF0&#x60; -  Category EF0  or higher (&gt;&#x3D; 40 mph estimated wind speeds) * &#x60;CAT_EF1&#x60; -  Category EF1  or higher (&gt;&#x3D; 73 mph estimated wind speeds) * &#x60;CAT_EF2&#x60; -  Category EF2  or higher (&gt;&#x3D; 113 mph estimated wind speeds) * &#x60;CAT_EF3&#x60; -  Category EF3  or higher (&gt;&#x3D; 158 mph estimated wind speeds) * &#x60;CAT_EF4&#x60; -  Category EF4  or higher (&gt;&#x3D; 207 mph estimated wind speeds) * &#x60;CAT_EF5&#x60; -  Category EF5  or higher (&gt;&#x3D; 260 mph estimated wind speeds)  
     * @return RiskTornadoPointObj
     */
    @Suppress("UNCHECKED_CAST")
    fun pointsLatitudelongitudeHazardsTornadoRecurrenceintervalRecurranceIntervalCategoryCategoryGet(latitude: kotlin.Float, longitude: kotlin.Float, recurranceInterval: kotlin.String, category: kotlin.String): RiskTornadoPointObj {
        
        val localVariableConfig = RequestConfig(
                RequestMethod.GET,
                "/points/{latitude},{longitude}/hazards/tornado/recurrenceinterval/{recurranceInterval}/category/{category}".replace("{" + "latitude" + "}", "$latitude").replace("{" + "longitude" + "}", "$longitude").replace("{" + "recurranceInterval" + "}", "$recurranceInterval").replace("{" + "category" + "}", "$category")
        )
        val response = request<RiskTornadoPointObj>(
                localVariableConfig
        )

        return when (response.responseType) {
            ResponseType.Success -> (response as Success<*>).data as RiskTornadoPointObj
            ResponseType.Informational -> TODO()
            ResponseType.Redirection -> TODO()
            ResponseType.ClientError -> throw ClientException((response as ClientError<*>).body as? String ?: "Client error")
            ResponseType.ServerError -> throw ServerException((response as ServerError<*>).message ?: "Server error")
        }
    }
    /**
     * The Tropical Cyclone risk for a Latitude/Longitude point.
     * Returns the Tropical Cyclone Risk Analytics data for a Latitude/Longitude point with the given recurrence interval and a magnitude at or higher than the specified category.          **IMPORTANT:** To authenticate to the Weather Source Risk Analytics API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     * @param latitude A latitude value between -90° and 90°. 
     * @param longitude A longitude value between -180° (West) and 180° (East). 
     * @param recurranceInterval The recurrence interval for the target risk.  Valid recurrence intervals are: * 1_YEAR * 5_YEAR * 10_YEAR * 20_YEAR  
     * @param category The category (Saffir-Simpson Scale) for the target risk. The risk corrolates to the selected category or higher. For example, CAT_1 would return risk for an event of category 1 or higher occuring.  Valid categories are: * &#x60;CAT_TS&#x60; - Category Tropical Storm (&gt;&#x3D; 34 knots sustained wind speed) * &#x60;CAT_1&#x60; - Category 1 or higher (&gt;&#x3D; 65 knots sustained wind speed) * &#x60;CAT_2&#x60; - Category 2 or higher (&gt;&#x3D; 74 knots sustained wind speed) * &#x60;CAT_3&#x60; - Category 3 or higher (&gt;&#x3D; 96 knots sustained wind speed) * &#x60;CAT_4&#x60; - Category 4 or higher (&gt;&#x3D; 114 knots sustained wind speed) * &#x60;CAT_5&#x60; - Category 5 (&gt;&#x3D; 135 knots sustained wind speed)  
     * @return RiskTropicalCyclonePointObj
     */
    @Suppress("UNCHECKED_CAST")
    fun pointsLatitudelongitudeHazardsTropicalcycloneRecurrenceintervalRecurranceIntervalCategoryCategoryGet(latitude: kotlin.Float, longitude: kotlin.Float, recurranceInterval: kotlin.String, category: kotlin.String): RiskTropicalCyclonePointObj {
        
        val localVariableConfig = RequestConfig(
                RequestMethod.GET,
                "/points/{latitude},{longitude}/hazards/tropicalcyclone/recurrenceinterval/{recurranceInterval}/category/{category}".replace("{" + "latitude" + "}", "$latitude").replace("{" + "longitude" + "}", "$longitude").replace("{" + "recurranceInterval" + "}", "$recurranceInterval").replace("{" + "category" + "}", "$category")
        )
        val response = request<RiskTropicalCyclonePointObj>(
                localVariableConfig
        )

        return when (response.responseType) {
            ResponseType.Success -> (response as Success<*>).data as RiskTropicalCyclonePointObj
            ResponseType.Informational -> TODO()
            ResponseType.Redirection -> TODO()
            ResponseType.ClientError -> throw ClientException((response as ClientError<*>).body as? String ?: "Client error")
            ResponseType.ServerError -> throw ServerException((response as ServerError<*>).message ?: "Server error")
        }
    }
    /**
     * The Tsunami risk for a Latitude/Longitude point.
     * Returns the Tsunami Risk Analytics data for a Latitude/Longitude point with the given recurrence interval and a magnitude at or higher than the specified category.          **IMPORTANT:** To authenticate to the Weather Source Risk Analytics API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     * @param latitude A latitude value between -90° and 90°. 
     * @param longitude A longitude value between -180° (West) and 180° (East). 
     * @param recurranceInterval The recurrence interval for the target risk.  Valid recurrence intervals are: * 1_YEAR * 5_YEAR * 10_YEAR * 20_YEAR * 50_YEAR * 75_YEAR * 100_YEAR  
     * @param category The category (Gutenberg Richter value) for the target risk. The risk corrolates to the selected category or higher. For example, CAT_1 would return risk for an event of category 1 or higher occuring.  Valid categories are: * &#x60;CAT_1&#x60; -  Category 1 or higher * &#x60;CAT_2&#x60; -  Category 2 or higher * &#x60;CAT_3&#x60; -  Category 3 or higher * &#x60;CAT_4&#x60; -  Category 4 or higher * &#x60;CAT_5&#x60; -  Category 5 or higher * &#x60;CAT_6&#x60; -  Category 6 or higher * &#x60;CAT_7&#x60; -  Category 7 or higher * &#x60;CAT_8&#x60; -  Category 8 or higher * &#x60;CAT_9&#x60; -  Category 9  
     * @return RiskTsunamiPointObj
     */
    @Suppress("UNCHECKED_CAST")
    fun pointsLatitudelongitudeHazardsTsunamiRecurrenceintervalRecurranceIntervalCategoryCategoryGet(latitude: kotlin.Float, longitude: kotlin.Float, recurranceInterval: kotlin.String, category: kotlin.String): RiskTsunamiPointObj {
        
        val localVariableConfig = RequestConfig(
                RequestMethod.GET,
                "/points/{latitude},{longitude}/hazards/tsunami/recurrenceinterval/{recurranceInterval}/category/{category}".replace("{" + "latitude" + "}", "$latitude").replace("{" + "longitude" + "}", "$longitude").replace("{" + "recurranceInterval" + "}", "$recurranceInterval").replace("{" + "category" + "}", "$category")
        )
        val response = request<RiskTsunamiPointObj>(
                localVariableConfig
        )

        return when (response.responseType) {
            ResponseType.Success -> (response as Success<*>).data as RiskTsunamiPointObj
            ResponseType.Informational -> TODO()
            ResponseType.Redirection -> TODO()
            ResponseType.ClientError -> throw ClientException((response as ClientError<*>).body as? String ?: "Client error")
            ResponseType.ServerError -> throw ServerException((response as ServerError<*>).message ?: "Server error")
        }
    }
    /**
     * The Volcano risk for a Latitude/Longitude point.
     * Returns the Volcano Risk Analytics data for a Latitude/Longitude point with the given recurrence interval and a magnitude at or higher than the specified category.          **IMPORTANT:** To authenticate to the Weather Source Risk Analytics API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     * @param latitude A latitude value between -90° and 90°. 
     * @param longitude A longitude value between -180° (West) and 180° (East). 
     * @param recurranceInterval The recurrence interval for the target risk.  Valid recurrence intervals are: * 1_YEAR * 5_YEAR * 10_YEAR * 20_YEAR * 50_YEAR * 75_YEAR * 100_YEAR  
     * @param category The category (Volcanic Explosive Index) for the target risk. The risk corrolates to the selected category or higher. For example, CAT_1 would return risk for an event of category 1 or higher occuring.  Valid categories are: * &#x60;CAT_1&#x60; -  Category 1 or higher * &#x60;CAT_2&#x60; -  Category 2 or higher * &#x60;CAT_3&#x60; -  Category 3 or higher * &#x60;CAT_4&#x60; -  Category 4 or higher * &#x60;CAT_5&#x60; -  Category 5 or higher * &#x60;CAT_6&#x60; -  Category 6 or higher * &#x60;CAT_7&#x60; -  Category 7 or higher * &#x60;CAT_8&#x60; -  Category 8 or higher * &#x60;CAT_9&#x60; -  Category 9  
     * @return RiskVolcanoPointObj
     */
    @Suppress("UNCHECKED_CAST")
    fun pointsLatitudelongitudeHazardsVolcanoRecurrenceintervalRecurranceIntervalCategoryCategoryGet(latitude: kotlin.Float, longitude: kotlin.Float, recurranceInterval: kotlin.String, category: kotlin.String): RiskVolcanoPointObj {
        
        val localVariableConfig = RequestConfig(
                RequestMethod.GET,
                "/points/{latitude},{longitude}/hazards/volcano/recurrenceinterval/{recurranceInterval}/category/{category}".replace("{" + "latitude" + "}", "$latitude").replace("{" + "longitude" + "}", "$longitude").replace("{" + "recurranceInterval" + "}", "$recurranceInterval").replace("{" + "category" + "}", "$category")
        )
        val response = request<RiskVolcanoPointObj>(
                localVariableConfig
        )

        return when (response.responseType) {
            ResponseType.Success -> (response as Success<*>).data as RiskVolcanoPointObj
            ResponseType.Informational -> TODO()
            ResponseType.Redirection -> TODO()
            ResponseType.ClientError -> throw ClientException((response as ClientError<*>).body as? String ?: "Client error")
            ResponseType.ServerError -> throw ServerException((response as ServerError<*>).message ?: "Server error")
        }
    }
    /**
     * The Wildfire risk for a Latitude/Longitude point.
     * Returns the Wildfire Risk Analytics data for a Latitude/Longitude point with the given recurrence interval and a magnitude at or higher than the specified category.          **IMPORTANT:** To authenticate to the Weather Source Risk Analytics API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     * @param latitude A latitude value between -90° and 90°. 
     * @param longitude A longitude value between -180° (West) and 180° (East). 
     * @param recurranceInterval The recurrence interval for the target risk.  Valid recurrence intervals are: * 1_YEAR * 5_YEAR * 10_YEAR * 20_YEAR  
     * @param category The category (Extremity of Fire Weather Risk) for the target risk. The risk corrolates to the selected category or higher. For example, CAT_1 would return risk for an event of category 1 or higher occuring.  Valid categories are: * &#x60;CAT_1&#x60; - Category 1 or higher * &#x60;CAT_2&#x60; - Category 2 or higher * &#x60;CAT_3&#x60; - Category 3 or higher * &#x60;CAT_4&#x60; - Category 4 or higher * &#x60;CAT_5&#x60; - Category 5 or higher * &#x60;CAT_6&#x60; - Category 6  
     * @return RiskWildfirePointObj
     */
    @Suppress("UNCHECKED_CAST")
    fun pointsLatitudelongitudeHazardsWildfireRecurrenceintervalRecurranceIntervalCategoryCategoryGet(latitude: kotlin.Float, longitude: kotlin.Float, recurranceInterval: kotlin.String, category: kotlin.String): RiskWildfirePointObj {
        
        val localVariableConfig = RequestConfig(
                RequestMethod.GET,
                "/points/{latitude},{longitude}/hazards/wildfire/recurrenceinterval/{recurranceInterval}/category/{category}".replace("{" + "latitude" + "}", "$latitude").replace("{" + "longitude" + "}", "$longitude").replace("{" + "recurranceInterval" + "}", "$recurranceInterval").replace("{" + "category" + "}", "$category")
        )
        val response = request<RiskWildfirePointObj>(
                localVariableConfig
        )

        return when (response.responseType) {
            ResponseType.Success -> (response as Success<*>).data as RiskWildfirePointObj
            ResponseType.Informational -> TODO()
            ResponseType.Redirection -> TODO()
            ResponseType.ClientError -> throw ClientException((response as ClientError<*>).body as? String ?: "Client error")
            ResponseType.ServerError -> throw ServerException((response as ServerError<*>).message ?: "Server error")
        }
    }
    /**
     * The current data version for all hazard data sources.
     * Returns the current data version for all hazard data sources.          **IMPORTANT:** To authenticate to the Weather Source Risk Analytics API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     * @return VersionsObj
     */
    @Suppress("UNCHECKED_CAST")
    fun versionsGet(): VersionsObj {
        
        val localVariableConfig = RequestConfig(
                RequestMethod.GET,
                "/versions"
        )
        val response = request<VersionsObj>(
                localVariableConfig
        )

        return when (response.responseType) {
            ResponseType.Success -> (response as Success<*>).data as VersionsObj
            ResponseType.Informational -> TODO()
            ResponseType.Redirection -> TODO()
            ResponseType.ClientError -> throw ClientException((response as ClientError<*>).body as? String ?: "Client error")
            ResponseType.ServerError -> throw ServerException((response as ServerError<*>).message ?: "Server error")
        }
    }
}
